@@ -49,18 +49,18 @@
 #'
 #' # repeated measures design
 #' long_to_wide_converter(
-#'   data = bugs_long,
-#'   x = condition,
-#'   y = desire,
+#'   data       = bugs_long,
+#'   x          = condition,
+#'   y          = desire,
 #'   subject.id = subject,
-#'   paired = TRUE
+#'   paired     = TRUE
 #' )
 #'
 #' # independent measures design
 #' long_to_wide_converter(
-#'   data = ggplot2::msleep,
-#'   x = vore,
-#'   y = brainwt,
+#'   data   = ggplot2::msleep,
+#'   x      = vore,
+#'   y      = brainwt,
 #'   paired = FALSE
 #' )
 #' @export
@@ -73,9 +73,6 @@ long_to_wide_converter <- function(data,
                                    paired = TRUE,
                                    spread = TRUE,
                                    ...) {
-  # for non-paired data, even if specified, ignore it
-  if (!paired) subject.id <- NULL
-
   # initial cleanup
   data %<>%
     select({{ x }}, {{ y }}, rowid = {{ subject.id }}) %>%
