@@ -6,7 +6,7 @@
 #' @inheritParams one_sample_test
 #' @inheritParams oneway_anova
 #' @inheritParams stats::t.test
-#' @inheritParams expr_template
+#' @inheritParams add_expression_col
 #'
 #' @description
 #'
@@ -29,19 +29,19 @@
 #' # between-subjects design
 #' two_sample_test(
 #'   data = sleep,
-#'   x = group,
-#'   y = extra,
+#'   x    = group,
+#'   y    = extra,
 #'   type = "p"
 #' )
 #'
 #' # within-subjects design
 #' two_sample_test(
-#'   data = dplyr::filter(bugs_long, condition %in% c("HDHF", "HDLF")),
-#'   x = condition,
-#'   y = desire,
-#'   paired = TRUE,
+#'   data       = dplyr::filter(bugs_long, condition %in% c("HDHF", "HDLF")),
+#'   x          = condition,
+#'   y          = desire,
+#'   paired     = TRUE,
 #'   subject.id = subject,
-#'   type = "p"
+#'   type       = "p"
 #' )
 #'
 #' # non-parametric ----------------------------------
@@ -49,19 +49,19 @@
 #' # between-subjects design
 #' two_sample_test(
 #'   data = sleep,
-#'   x = group,
-#'   y = extra,
+#'   x    = group,
+#'   y    = extra,
 #'   type = "np"
 #' )
 #'
 #' # within-subjects design
 #' two_sample_test(
-#'   data = dplyr::filter(bugs_long, condition %in% c("HDHF", "HDLF")),
-#'   x = condition,
-#'   y = desire,
-#'   paired = TRUE,
+#'   data       = dplyr::filter(bugs_long, condition %in% c("HDHF", "HDLF")),
+#'   x          = condition,
+#'   y          = desire,
+#'   paired     = TRUE,
 #'   subject.id = subject,
-#'   type = "np"
+#'   type       = "np"
 #' )
 #'
 #' # robust ----------------------------------
@@ -69,19 +69,19 @@
 #' # between-subjects design
 #' two_sample_test(
 #'   data = sleep,
-#'   x = group,
-#'   y = extra,
+#'   x    = group,
+#'   y    = extra,
 #'   type = "r"
 #' )
 #'
 #' # within-subjects design
 #' two_sample_test(
-#'   data = dplyr::filter(bugs_long, condition %in% c("HDHF", "HDLF")),
-#'   x = condition,
-#'   y = desire,
-#'   paired = TRUE,
+#'   data       = dplyr::filter(bugs_long, condition %in% c("HDHF", "HDLF")),
+#'   x          = condition,
+#'   y          = desire,
+#'   paired     = TRUE,
 #'   subject.id = subject,
-#'   type = "r"
+#'   type       = "r"
 #' )
 #'
 #' #' # Bayesian ------------------------------
@@ -89,19 +89,19 @@
 #' # between-subjects design
 #' two_sample_test(
 #'   data = sleep,
-#'   x = group,
-#'   y = extra,
+#'   x    = group,
+#'   y    = extra,
 #'   type = "bayes"
 #' )
 #'
 #' # within-subjects design
 #' two_sample_test(
-#'   data = dplyr::filter(bugs_long, condition %in% c("HDHF", "HDLF")),
-#'   x = condition,
-#'   y = desire,
-#'   paired = TRUE,
+#'   data       = dplyr::filter(bugs_long, condition %in% c("HDHF", "HDLF")),
+#'   x          = condition,
+#'   y          = desire,
+#'   paired     = TRUE,
 #'   subject.id = subject,
-#'   type = "bayes"
+#'   type       = "bayes"
 #' )
 #' }
 #' @export
@@ -132,55 +132,53 @@ two_sample_test <- function(data,
   # properly removing NAs if it's a paired design
   data %<>%
     long_to_wide_converter(
-      x = {{ x }},
-      y = {{ y }},
+      x          = {{ x }},
+      y          = {{ y }},
       subject.id = {{ subject.id }},
-      paired = paired,
-      spread = ifelse(type %in% c("bayes", "robust"), paired, FALSE)
+      paired     = paired,
+      spread     = ifelse(type %in% c("bayes", "robust"), paired, FALSE)
     )
 
   # parametric ---------------------------------------
 
   if (type == "parametric") {
+    # styler: off
     # preparing expression parameters
-    c(no.parameters, k.df) %<-% c(1L, ifelse(paired || var.equal, 0L, k))
-    .f <- stats::t.test
-
+    k.df <- ifelse(paired || var.equal, 0L, k)
+    .f   <- stats::t.test
     if (effsize.type %in% c("unbiased", "g")) .f.es <- effectsize::hedges_g
-    if (effsize.type %in% c("biased", "d")) .f.es <- effectsize::cohens_d
+    if (effsize.type %in% c("biased", "d")) .f.es   <- effectsize::cohens_d
+    # styler: on
   }
 
   # non-parametric ------------------------------------
 
-  if (type == "nonparametric") {
-    # preparing expression parameters
-    no.parameters <- 0L
-    c(.f, .f.es) %<-% c(stats::wilcox.test, effectsize::rank_biserial)
-  }
+  # preparing expression parameters
+  if (type == "nonparametric") c(.f, .f.es) %<-% c(stats::wilcox.test, effectsize::rank_biserial)
 
   # preparing expression
   if (type %in% c("parametric", "nonparametric")) {
     # extracting test details
     stats_df <- exec(
       .f,
-      formula = new_formula(y, x),
-      data = data,
-      paired = paired,
+      formula     = new_formula(y, x),
+      data        = data,
+      paired      = paired,
       alternative = alternative,
-      var.equal = var.equal,
-      exact = FALSE
+      var.equal   = var.equal,
+      exact       = FALSE
     ) %>%
       tidy_model_parameters(.)
 
     # extracting effect size details
     effsize_df <- exec(
       .f.es,
-      x = new_formula(y, x),
-      data = data,
-      paired = paired,
-      pooled_sd = FALSE,
-      ci = conf.level,
-      verbose = FALSE
+      x           = new_formula(y, x),
+      data        = data,
+      paired      = paired,
+      pooled_sd   = FALSE,
+      ci          = conf.level,
+      verbose     = FALSE
     ) %>%
       tidy_model_effectsize(.)
   }
@@ -189,23 +187,26 @@ two_sample_test <- function(data,
 
   if (type == "robust") {
     # expression parameters
-    c(no.parameters, k.df) %<-% c(1L, ifelse(paired, 0L, k))
-
-    # common arguments
-    .f.args <- list(formula = new_formula(y, x), data = data, x = data[[2]], y = data[[3]])
-    .f.es.args <- list(EQVAR = FALSE, nboot = nboot, alpha = 1 - conf.level, tr = tr)
+    k.df <- ifelse(paired, 0L, k)
 
+    # styler: off
     # which functions to be used for hypothesis testing and estimation?
     if (!paired) c(.f, .f.es) %<-% c(WRS2::yuen, WRS2::akp.effect)
-    if (paired) c(.f, .f.es) %<-% c(WRS2::yuend, WRS2::dep.effect)
+    if (paired) c(.f, .f.es)  %<-% c(WRS2::yuend, WRS2::dep.effect)
+    # styler: on
+
+    # common arguments
+    # styler: off
+    .f.args    <- list(formula = new_formula(y, x), data = data, x = data[[2]], y = data[[3]])
+    .f.es.args <- list(EQVAR = FALSE, nboot = nboot, alpha = 1 - conf.level, tr = tr)
 
     effsize_df <- tidy_model_parameters(exec(.f.es, !!!.f.args, !!!.f.es.args), keep = "AKP")
-    stats_df <- tidy_model_parameters(exec(.f, !!!.f.args, !!!.f.es.args))
+    stats_df   <- tidy_model_parameters(exec(.f,    !!!.f.args, !!!.f.es.args))
+    # styler: on
   }
 
-  # final returns
+  # combining dataframes
   if (type != "bayes") {
-    # combining dataframes
     stats_df <- bind_cols(select(stats_df, -matches("^est|^eff|conf|^ci")), select(effsize_df, -matches("term")))
   }
 
@@ -213,8 +214,10 @@ two_sample_test <- function(data,
 
   # running Bayesian t-test
   if (type == "bayes") {
+    # styler: off
     if (!paired) .f.args <- list(formula = new_formula(y, x), paired = paired)
-    if (paired) .f.args <- list(x = data[[2]], y = data[[3]], paired = paired)
+    if (paired) .f.args  <- list(x = data[[2]], y = data[[3]], paired = paired)
+    # styler: on
 
     # creating a `BayesFactor` object
     stats_df <- exec(BayesFactor::ttestBF, data = as.data.frame(data), rscale = bf.prior, !!!.f.args) %>%
@@ -223,16 +226,13 @@ two_sample_test <- function(data,
 
   # expression ---------------------------------------
 
-  # return the output
-  polish_data(stats_df) %>%
-    mutate(expression = list(expr_template(
-      no.parameters = no.parameters,
-      data = .,
-      paired = paired,
-      n = ifelse(paired, length(unique(data$rowid)), nrow(data)),
-      k = k,
-      k.df = k.df,
-      top.text = top.text,
-      bayesian = ifelse(type == "bayes", TRUE, FALSE)
-    )))
+  # add column with expression
+  add_expression_col(
+    data     = stats_df,
+    paired   = paired,
+    n        = ifelse(paired, length(unique(data$rowid)), nrow(data)),
+    k        = k,
+    k.df     = k.df,
+    top.text = top.text
+  )
 }
