@@ -19,7 +19,7 @@ test_that(
     # testing all details
     set.seed(123)
     expect_snapshot(select(df1, -expression))
-    expect_snapshot(df1$expression[[1]])
+    expect_snapshot(as.character(df1$expression[[1]]))
 
     # `{statsExpressions}` output
     set.seed(123)
@@ -33,7 +33,7 @@ test_that(
     # testing all details
     set.seed(123)
     expect_snapshot(select(df2, -expression))
-    expect_snapshot(df2$expression[[1]])
+    expect_snapshot(as.character(df2$expression[[1]]))
   }
 )
 
@@ -56,7 +56,7 @@ test_that(
     # testing all details
     set.seed(123)
     expect_snapshot(select(df, -expression))
-    expect_snapshot(df$expression[[1]])
+    expect_snapshot(as.character(df$expression[[1]]))
   }
 )
 
@@ -79,7 +79,7 @@ test_that(
     # testing all details
     set.seed(123)
     expect_snapshot(select(df, -expression))
-    expect_snapshot(df$expression[[1]])
+    expect_snapshot(as.character(df$expression[[1]]))
   }
 )
 
@@ -109,10 +109,10 @@ test_that(
         data = iris,
         y = Sepal.Length,
         x = Sepal.Width,
-        top.text = "huh"
+        top.text = "huh is duh"
       )
 
-    expect_snapshot(subtitle1$expression[[1]])
+    expect_snapshot(as.character(subtitle1$expression[[1]]))
   }
 )
 
@@ -144,6 +144,6 @@ test_that(
       conf.level = 0.99
     )
 
-    expect_snapshot(subtitle1$expression[[1]])
+    expect_snapshot(as.character(subtitle1$expression[[1]]))
   }
 )
